import * as domino from 'domino';
import { Renderer } from './abstract.renderer.js';
import { getStaticFiles } from '../util/misc.js';
import { config } from '../config.js';
import MediaWiki from '../MediaWiki.js';
import { htmlWikimediaMobileTemplateCode } from '../Templates.js';
import { genCanonicalLink, genHeaderScript, genHeaderCSSLink } from '../util/misc.js';
export class MobileRenderer extends Renderer {
    staticFilesListMobile = [];
    constructor() {
        super();
        this.staticFilesListMobile = this.staticFilesListCommon.concat(getStaticFiles(config.output.wikimediaMobileJsResources, config.output.wikimediaMobileCssResources));
    }
    filterWikimediaMobileModules(_moduleDependencies) {
        const { jsDependenciesList, styleDependenciesList } = _moduleDependencies;
        const wikimediaMobileJsModuleDependencies = jsDependenciesList.filter((item) => item.includes('javascript/mobile'));
        const wikimediaMobileCssModuleDependencies = styleDependenciesList.filter((item) => item.includes('css/mobile'));
        const wikimediaMobileModuleDependencies = {
            jsDependenciesList: wikimediaMobileJsModuleDependencies,
            styleDependenciesList: wikimediaMobileCssModuleDependencies,
        };
        return wikimediaMobileModuleDependencies;
    }
    genWikimediaMobileOverrideCSSLink(css) {
        return `<link rel="stylesheet" href="../-/${css}.css" />`;
    }
    genWikimediaMobileOverrideScript(js) {
        return `<script src='../-/${js}.js'></script>`;
    }
    templateMobileArticle(moduleDependencies, articleId) {
        const { jsDependenciesList, styleDependenciesList } = moduleDependencies;
        const htmlTemplateString = htmlWikimediaMobileTemplateCode()
            .replace('__ARTICLE_CANONICAL_LINK__', genCanonicalLink(config, MediaWiki.webUrl.href, articleId))
            .replace('__ARTICLE_CONFIGVARS_LIST__', '')
            .replace('__JS_SCRIPTS__', this.genWikimediaMobileOverrideScript(config.output.wikimediaMobileJsResources[0]))
            .replace('__CSS_LINKS__', this.genWikimediaMobileOverrideCSSLink(config.output.wikimediaMobileCssResources[0]))
            .replace('__ARTICLE_JS_LIST__', jsDependenciesList.length !== 0 ? jsDependenciesList.map((oneJsDep) => genHeaderScript(config, oneJsDep, articleId, config.output.dirs.mediawiki)).join('\n') : '')
            .replace('__ARTICLE_CSS_LIST__', styleDependenciesList.length !== 0
            ? styleDependenciesList.map((oneCssDep) => genHeaderCSSLink(config, oneCssDep, articleId, config.output.dirs.mediawiki)).join('\n')
            : '');
        const htmlTemplateDoc = domino.createDocument(htmlTemplateString);
        return htmlTemplateDoc;
    }
}
//# sourceMappingURL=abstractMobile.render.js.map